@@ -6,7 +6,7 @@ key = ""
 
 def _get_uuid(username):
     try:
-        return requests.request("GET", f"https://playerdb.co/api/player/minecraft/{username}")['player']['meta']['raw_id']
+        return requests.request("GET", f"https://playerdb.co/api/player/minecraft/{username}")['data']['player']['meta']['raw_id']
     except:
         raise UUIDNotFoundError(f"A UUID could not be found for {username}")
 
